CREATE TABLE [dbo].[Office_Calendar](
	[EventId] [bigint] IDENTITY(1,1) NOT NULL,
	[EventType] [nvarchar](50) NULL,
	[EventTitle] [nvarchar](200) NOT NULL,
	[EventLocation] [nvarchar](50) NULL,
	[EventDescription] [ntext] NULL,
	[UserId] [nvarchar](50) NOT NULL,
	[UserName] [nvarchar](100) NOT NULL,
	[DeptName] [ntext] NOT NULL,
	[StartTime] [datetime] NOT NULL,
	[EndTime] [datetime] NULL,
	[IsAllDay] [bit] NOT NULL CONSTRAINT [DF_Office_Calendar_IsAllDay] DEFAULT ((0)),
	[RecurrenceRule] [ntext] NULL,
	[AttachmentId] [nvarchar](50) NULL,
	[AddTime] [datetime] NOT NULL CONSTRAINT [DF_Office_Calendar_AddTime] DEFAULT (getdate()),
	[ManagerUserId] [nvarchar](50) NULL,
	[ManagerUserName] [nvarchar](100) NULL,
	[ManagerDeptName] [ntext] NULL,
	[ManagerAttachmentId] [nvarchar](50) NULL,
	[ManagerSubmitDescription] [ntext] NULL,
	[ManagerSubmitTime] [datetime] NULL,
	CONSTRAINT [PK_Office_Calendar] PRIMARY KEY CLUSTERED 
	(
		[EventId] ASC
	)
)
GO

CREATE TABLE [dbo].[Office_Email] (
	[EmailId] [bigint] IDENTITY (1, 1) NOT NULL,
	[FromId] [nvarchar] (50) NOT NULL,
	[FromUserName] [nvarchar] (100) NOT NULL,
	[FromDeptName] [ntext] NULL,
	[ToId] [nvarchar] (50) NULL,
	[ToUserName] [nvarchar] (100) NULL,
	[ToDeptName] [ntext] NULL,
	[ToIds] [ntext] NULL,
	[Subject] [nvarchar] (200) NOT NULL,
	[EmailContent] [ntext] NULL,
	[SendTime] [datetime] NOT NULL CONSTRAINT [DF_Office_Email_SendTime] DEFAULT (getdate()),
	[AttachmentId] [nvarchar] (50) NULL,
	[ReadFlag] [bit] NOT NULL CONSTRAINT [DF_Office_Email_ReadFlag] DEFAULT (0),
	[DeleteFlag] [int] NOT NULL CONSTRAINT [DF_Office_Email_DeleteFlag] DEFAULT (0),
	[TotalSize] [bigint] NOT NULL CONSTRAINT [DF_Office_Email_TotalSize] DEFAULT (0),
	[Important] [int] NOT NULL CONSTRAINT [DF_Office_Email_Important] DEFAULT (0)
	CONSTRAINT [PK_Office_Email] PRIMARY KEY  CLUSTERED 
	(
		[EmailId]
	)
)
GO

CREATE TABLE [dbo].[Office_Announcement] (
	[AnnouncementId] [bigint] IDENTITY (1, 1) NOT NULL,
	[UserId] [nvarchar] (50) NOT NULL,
	[UserName] [nvarchar] (100) NOT NULL,
	[DeptName] [ntext] NULL,
	[ToId] [nvarchar] (800) NULL,
	[ToUser] [nvarchar] (800) NULL,
	[Subject] [nvarchar] (200) NOT NULL,
	[AnnouncementContent] [ntext] NULL,
	[SendTime] [datetime] NOT NULL CONSTRAINT [DF_Office_Announcement_SendTime] DEFAULT (getdate()),
	[BeginDate] [datetime] NULL,
	[EndDate] [datetime] NULL,
	[AttachmentId] [nvarchar] (50) NULL,
	[Important] [bit] NOT NULL CONSTRAINT [DF_Office_Announcement_Important] DEFAULT (0),
	[ViewCount] int NULL,
	[CommentCount] [int] NOT NULL CONSTRAINT [DF_Office_Announcement_CommentCount] DEFAULT (0),
	[Readers] [ntext] NULL,
	CONSTRAINT [PK_Office_Announcement] PRIMARY KEY  CLUSTERED 
	(
		[AnnouncementId]
	)
)
GO

CREATE TABLE [dbo].[Office_Announcement_Comment] (
	[CommentId] [bigint] IDENTITY (1, 1) NOT NULL,
	[AnnouncementId] [bigint] NOT NULL,
	[UserId] [nvarchar] (50) NOT NULL,
	[UserName] [nvarchar] (100) NOT NULL,
	[DeptName] [ntext] NULL,
	[CommentContent] [ntext] NULL,
	[ReplyTime] [datetime] NOT NULL CONSTRAINT [DF_Office_Announcement_Comment_ReplyTime] DEFAULT (getdate()),
	CONSTRAINT [PK_Office_Announcement_Comment] PRIMARY KEY  CLUSTERED 
	(
		[CommentId]
	)
)
GO

CREATE TABLE [dbo].[Office_News] (
	[NewsId] [bigint] IDENTITY (1, 1) NOT NULL,
	[UserId] [nvarchar] (50) NOT NULL,
	[UserName] [nvarchar] (100) NOT NULL,
	[DeptName] [ntext] NULL,
	[ToId] [nvarchar] (4000) NULL,
	[ToUser] [nvarchar] (4000) NULL,
	[Subject] [nvarchar] (200) NOT NULL,
	[NewsContent] [ntext] NULL,
	[SendTime] [datetime] NOT NULL CONSTRAINT [DF_Office_News_SendTime] DEFAULT (getdate()),
	[AttachmentId] [nvarchar] (50) NULL,
	[ViewCount] [int] NOT NULL CONSTRAINT [DF_Office_News_ViewCount] DEFAULT (0),
	[CommentCount] [int] NOT NULL CONSTRAINT [DF_Office_News_CommentCount] DEFAULT (0),
	[Readers] [ntext] NULL,
	CONSTRAINT [PK_Office_News] PRIMARY KEY  CLUSTERED 
	(
		[NewsId]
	)
)
GO

CREATE TABLE [dbo].[Office_News_Comment] (
	[CommentId] [bigint] IDENTITY (1, 1) NOT NULL,
	[NewsId] [bigint] NOT NULL,
	[UserId] [nvarchar] (50) NOT NULL,
	[UserName] [nvarchar] (100) NOT NULL,
	[DeptName] [ntext] NULL,
	[CommentContent] [ntext] NULL,
	[ReplyTime] [datetime] NOT NULL CONSTRAINT [DF_Office_News_Comment_ReplyTime] DEFAULT (getdate()),
	CONSTRAINT [PK_Office_News_Comment] PRIMARY KEY  CLUSTERED 
	(
		[CommentId]
	)
)
GO

CREATE TABLE [dbo].[Office_WorkReport](
	[ReportId] [bigint] IDENTITY(1,1) NOT NULL,
	[FromUserId] [nvarchar](50) NOT NULL,
	[FromUserName] [nvarchar](100) NOT NULL,
	[FromDeptName] [ntext] NULL,
	[ToUserId] [nvarchar](50) NULL,
	[ToUserName] [nvarchar](100) NULL,
	[ToDeptName] [ntext] NULL,
	[ReportTitle] [nvarchar](200) NOT NULL,
	[ReportType] [nvarchar](100) NOT NULL,
	[ReportContent] [ntext] NULL,
	[ReportTime] [datetime] NOT NULL CONSTRAINT [DF_Office_WorkReport_ReportTime]  DEFAULT (getdate()),
	[AttachmentId] [nvarchar](50) NULL,
	[CommentContent] [ntext] NULL,
	[CommentTime] [datetime] NULL,
	[ReadFlag] [bit] NOT NULL CONSTRAINT [DF_Office_WorkReport_ReadFlag]  DEFAULT ((0)),
	[Important] [bit] NOT NULL CONSTRAINT [DF_Office_WorkReport_Important]  DEFAULT ((0)),
	[DeleteFlag] [int] NOT NULL CONSTRAINT [DF_Office_WorkReport_DeleteFlag]  DEFAULT ((0)),
	CONSTRAINT [PK_Office_WorkReport] PRIMARY KEY CLUSTERED 
	(
		[ReportId] ASC
	)
)
GO

CREATE TABLE [dbo].[Office_Wordpad](
	[WordId] [bigint] IDENTITY(1,1) NOT NULL,
	[UserId] [nvarchar](50) NOT NULL,
	[WordSubject] [nvarchar](500) NOT NULL,
	[WordContent] [ntext] NOT NULL,
	[WordAttachmentId] [nvarchar] (50) NULL,
	[MoreOptions] [ntext] NULL,
	[WordTime] [datetime] NOT NULL CONSTRAINT [DF_Office_Wordpad_WordTime] DEFAULT (getdate()),
	CONSTRAINT [PK_Office_Wordpad] PRIMARY KEY CLUSTERED 
	(
		[WordId] ASC
	)
)
GO

CREATE TABLE [dbo].[Office_Files] (
	[AttachId] [bigint] IDENTITY (1, 1) NOT NULL,
	[AttachType] [nvarchar] (50)  NOT NULL,
	[AttachmentId] [nvarchar] (50) NOT NULL,
	[Name] [nvarchar] (200) NOT NULL,	
	[UserId] [nvarchar] (50) NULL,
	[UserName] [nvarchar] (100) NULL,
	[DeptName] [ntext] NULL,
	[AddTime] [datetime] NOT NULL CONSTRAINT [DF_Office_Files_AddTime] DEFAULT (getdate()),
	[AddIp] [nvarchar] (50) NULL,
	[ContentType] [nvarchar] (200) NULL,
	[ContentLength] [bigint] NOT NULL CONSTRAINT [DF_Office_Files_ContentLength] DEFAULT (0),	
	[Guid] [uniqueidentifier] NULL CONSTRAINT [DF_Office_Files_Guid] DEFAULT (NEWSEQUENTIALID()),
	[DeleteFlag] [bit] NOT NULL CONSTRAINT [DF_Office_Files_DeleteFlag] DEFAULT (0),
	CONSTRAINT [PK_Office_Files] PRIMARY KEY  CLUSTERED 
	(
		[AttachId]
	)
)
GO

CREATE TABLE [dbo].[Team_Work] (
	[TeamId] [bigint] IDENTITY (1, 1) NOT NULL,
	[Name] [nvarchar] (200) NOT NULL,
	[WorkContent] [ntext] NULL,
	[ToId] [nvarchar] (800) NULL,
	[Participator] [nvarchar] (800) NULL,
	[Manager] [nvarchar] (800) NULL,
	[AttachmentId] [nvarchar] (50) NULL,
	[FileAttachmentId] [nvarchar] (50) NULL,
	[CompletedPercent] [int] NOT NULL CONSTRAINT [DF_Team_Work_CompletedPercent] DEFAULT (0),
	[Status] [int] NOT NULL,
	[CreateDate] [datetime] NOT NULL CONSTRAINT [DF_Team_Work_CreateDate] DEFAULT (getdate()),
	[Creator] [nvarchar] (50) NOT NULL,
	[CreatorUserName] [nvarchar] (100) NOT NULL,
	[CreatorDeptName] [ntext] NULL,
	CONSTRAINT [PK_Team_Work] PRIMARY KEY  CLUSTERED 
	(
		[TeamId]
	)
)
GO

CREATE TABLE [dbo].[Team_Comment](
	[CommentId] [bigint] IDENTITY(1,1) NOT NULL,
	[CommentGuid] [uniqueidentifier] NOT NULL CONSTRAINT [DF_Team_Comment_CommentGuid]  DEFAULT (NEWSEQUENTIALID()),
	[ParentGuid] [uniqueidentifier] NULL,
	[TeamId] [bigint] NOT NULL,
	[CommentTime] [datetime] NOT NULL CONSTRAINT [DF_Team_Comment_CommentTime] DEFAULT (getdate()),
	[CommentContent] [text] NOT NULL,
	[AttachmentId] [nvarchar](50) NULL,
	[CommentUserId] [nvarchar](50) NULL,
	[CommentUserName] [nvarchar] (100) NOT NULL,
	[CommentDeptName] [ntext] NULL,
	CONSTRAINT [PK_Team_Comment] PRIMARY KEY CLUSTERED 
	(
		[CommentId]
	)
)
GO

CREATE TABLE [dbo].[Team_Log] (
	[LogId] [bigint] IDENTITY (1, 1) NOT NULL,
	[TeamId] [bigint] NOT NULL,
	[LogTime] [datetime] NOT NULL CONSTRAINT [DF_Team_Log_LogTime] DEFAULT (getdate()),
	[Progress] [nvarchar] (50) NULL,
	[LogContent] [ntext] NULL,
	[AttachmentId] [nvarchar] (50) NULL,
	[LogUserId] [nvarchar] (50) NOT NULL,
	[LogUserName] [nvarchar] (100) NOT NULL,
	[LogDeptName] [ntext] NULL,
	CONSTRAINT [PK_Team_Log] PRIMARY KEY  CLUSTERED 
	(
		[LogId]
	)
)
GO

CREATE TABLE [dbo].[Department] (
	[DeptId] [int] IDENTITY (1, 1) NOT NULL,
	[DeptNo] [int] NOT NULL CONSTRAINT [DF_Department_DeptNo] DEFAULT (10),	
	[ParentDept] [int] NOT NULL CONSTRAINT [DF_Department_ParentDept] DEFAULT (0),
	[DeptName] [nvarchar] (200) NOT NULL,	
	[Manager] [nvarchar] (100) NULL,
	[Leader] [nvarchar] (100) NULL,
	[TelNo] [nvarchar] (50) NULL,
	[DeptFunc] [ntext] NULL,
	CONSTRAINT [PK_Department] PRIMARY KEY  CLUSTERED 
	(
		[DeptId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Files] (
	[AttachId] [bigint] IDENTITY (1, 1) NOT NULL,
	[AttachType] [nvarchar] (50)  NOT NULL,
	[AttachmentId] [nvarchar] (50) NOT NULL,
	[Name] [nvarchar] (200) NOT NULL,	
	[UserId] [nvarchar] (50) NULL,
	[UserName] [nvarchar] (100) NULL,
	[DeptName] [ntext] NULL,
	[AddTime] [datetime] NOT NULL CONSTRAINT [DF_Flow_Files_AddTime] DEFAULT (getdate()),
	[AddIp] [nvarchar] (50) NULL,
	[AddRemark] [ntext] NULL,
	[ContentType] [nvarchar] (200) NULL,
	[ContentLength] [bigint] NOT NULL CONSTRAINT [DF_Flow_Files_ContentLength] DEFAULT (0),
	[Guid] [uniqueidentifier] NULL CONSTRAINT [DF_Flow_Files_Guid] DEFAULT (NEWSEQUENTIALID()),
	[DeleteFlag] [bit] NOT NULL CONSTRAINT [DF_Flow_Files_DeleteFlag] DEFAULT (0),
	CONSTRAINT [PK_Flow_Files] PRIMARY KEY  CLUSTERED 
	(
		[AttachId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Form](
	[FormId] [int] IDENTITY(1,1) NOT NULL,
	[FormName] [nvarchar](200) NOT NULL,
	[FormLanguage] [ntext] NULL,
	[FormLabel] [nvarchar](50) NULL,
	[FormRemark] [ntext] NULL,
	[FormModel] [ntext] NULL,	
	[FormSetting] [ntext] NULL,	
	[FormScript] [ntext] NULL,
	[CssPdf] [ntext] NULL,
	[HeaderPdf] [ntext] NULL,
	[FooterPdf] [ntext] NULL,
	[CssHtml] [ntext] NULL,
	[CssDocx] [ntext] NULL,
	[DelFlag] [int] NOT NULL CONSTRAINT [DF_Flow_Form_DelFlag] DEFAULT (0),
	[IsSeal] [bit] NOT NULL CONSTRAINT [DF_Flow_Form_IsSeal] DEFAULT (0),
	CONSTRAINT [PK_Flow_Form] PRIMARY KEY CLUSTERED 
	(
		[FormId] ASC
	)
)
GO

CREATE TABLE [dbo].[Flow_Type] (
	[FlowId] [int] IDENTITY (1, 1) NOT NULL,
	[FlowSort] [int] NOT NULL CONSTRAINT [DF_Flow_Type_FlowSort] DEFAULT (0),
	[FlowNo] [int] NOT NULL CONSTRAINT [DF_Flow_Type_FlowNo] DEFAULT (1),
	[FlowName] [nvarchar] (200) NOT NULL,	
	[FlowType] [int] NOT NULL,
	[FormId] [int] NULL,
	[FormId2] [int] NULL,
	[FormId3] [int] NULL,
	[RuleOther] [int] NOT NULL CONSTRAINT [DF_Flow_Type_RuleOther] DEFAULT (2),
	[FlowDoc] [bit] NOT NULL CONSTRAINT [DF_Flow_Type_FlowDoc] DEFAULT (0),
	[NewUser] [nvarchar] (800) NULL,
	[NewDept] [nvarchar] (800) NULL CONSTRAINT [DF_Flow_Type_NewDept] DEFAULT (N'ALL_DEPT'),
	[ManageUser] [nvarchar] (800) NULL,
	[QueryUser] [nvarchar] (800) NULL,
	[AutoName] [ntext] NULL,
	[AutoCounter] [bigint] NOT NULL CONSTRAINT [DF_Flow_Type_AutoCounter] DEFAULT (0),
	[AutoLen] [int] NOT NULL CONSTRAINT [DF_Flow_Type_AutoLen] DEFAULT (0),
	[AutoEdit] [int] NOT NULL CONSTRAINT [DF_Flow_Type_AutoEdit] DEFAULT (0),
	[TitleItem] ntext NULL,
	[QueryItem] [ntext] NULL,
	[QueryExcel] [bit] NOT NULL CONSTRAINT [DF_Flow_Type_QueryExcel] DEFAULT (1),
	[DocxSplitPrint] [bit] NOT NULL CONSTRAINT [DF_Flow_Type_DocxSplitPrint] DEFAULT (1),
	[PdfSplitPrint] [bit] NOT NULL CONSTRAINT [DF_Flow_Type_PdfSplitPrint] DEFAULT (1),
	[PrintTemplate] nvarchar(200) NULL CONSTRAINT [DF_Flow_Type_PrintTemplate] DEFAULT (N'Signature,Attach,Comment,Diagram'),
	[DelFlag] [int] NOT NULL CONSTRAINT [DF_Flow_Type_DelFlag] DEFAULT (0),
	[FlowDesc] [ntext] NULL,
	CONSTRAINT [PK_Flow_Type] PRIMARY KEY  CLUSTERED 
	(
		[FlowId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Process] (
	[ProcessId] [int] IDENTITY (1, 1) NOT NULL,
	[FlowId] [int] NOT NULL,
	[PrcsId] [int] NOT NULL CONSTRAINT [DF_Flow_Process_PrcsId] DEFAULT (0),
	[PrcsName] [nvarchar] (200) NOT NULL,
	[PrcsGuid] [uniqueidentifier] NOT NULL CONSTRAINT [DF_Flow_Process_PrcsGuid]  DEFAULT (NEWSEQUENTIALID()),
	[FormsTitle] [nvarchar](100) NULL,
	[FormsId] [int] NULL,
	[FormsVerifyType] [nvarchar](20) NULL,
	[FormsBeginUser] [ntext] NULL,
	[FormsRandom] [nvarchar](50) NULL,
	[FormsPassword] [nvarchar](50) NULL,
	[FormsAttach] bit NOT NULL CONSTRAINT [DF_FormsAttach] DEFAULT (0),
	[FormsEmail] [nvarchar](200),
	[FormsLanguage] [nvarchar](20),
	[PrcsItem] [ntext] NULL,
	[AutoItem] [ntext] NULL,
	[HiddenItem] [ntext] NULL,
	[PrcsUser] [nvarchar] (800) NULL,
	[PrcsDept] [nvarchar] (800) NULL CONSTRAINT [DF_Flow_Process_PrcsDept] DEFAULT (N'ALL_DEPT'),
	[PrcsTo] [ntext] NULL,
	[SetLeft] [int] NOT NULL CONSTRAINT [DF_Flow_Process_SetLeft] DEFAULT (0),
	[SetTop] [int] NOT NULL CONSTRAINT [DF_Flow_Process_SetTop] DEFAULT (0),
	[ConditionIn] [ntext] NULL,
	[ConditionInFormula] [ntext] NULL,
	[ConditionOut] [ntext] NULL,
	[ConditionOutFormula] [ntext] NULL,
	[ConditionDesc] [ntext] NULL,	
	[Comment] [int] NOT NULL CONSTRAINT [DF_Flow_Process_Comment] DEFAULT (0),
	[TurnPriv] [int] NOT NULL CONSTRAINT [DF_Flow_Process_TurnPriv] DEFAULT (1),
	[UserFilter] [int] NOT NULL CONSTRAINT [DF_Flow_Process_UserFilter] DEFAULT (0),
	[AutoType] [int] NOT NULL CONSTRAINT [DF_Flow_Process_AutoType] DEFAULT (0),
	[UserLock] [int] NOT NULL CONSTRAINT [DF_Flow_Process_UserLock] DEFAULT (0),
	[TopDefault] [bit] NOT NULL CONSTRAINT [DF_Flow_Process_TopDefault] DEFAULT (0),
	[AutoUserOp] [nvarchar] (50) NULL,
	[AutoUser] [nvarchar] (800) NULL,	
	[AllowBack] [int] NOT NULL CONSTRAINT [DF_Flow_Process_AllowBack] DEFAULT (0),
	[TimeOut] [int] NULL,
	[AttachPriv] [nvarchar] (50) NULL CONSTRAINT [DF_Flow_Process_AttachPriv] DEFAULT (N'new,del,'),
	CONSTRAINT [PK_Flow_Process] PRIMARY KEY  CLUSTERED 
	(
		[ProcessId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Rule] (
	[RuleId] [int] IDENTITY (1, 1) NOT NULL,
	[FlowId] [int] NULL,
	[UserId] [nvarchar] (50) NOT NULL,
	[ToId] [nvarchar] (50) NOT NULL,
	[BeginDate] [datetime] NULL,
	[EndDate] [datetime] NULL,
	CONSTRAINT [PK_Flow_Rule] PRIMARY KEY  CLUSTERED 
	(
		[RuleId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Run] (
	[RunId] [bigint] IDENTITY (1, 1) NOT NULL,
	[RunGuid] [uniqueidentifier] NOT NULL CONSTRAINT [DF_Flow_Run_Guid] DEFAULT (NEWSEQUENTIALID()),
	[SubRunId] [bigint] NULL,
	[AutoCounter] [bigint] NULL,
	[RunName] [nvarchar] (500) NOT NULL,
	[FlowId] [int] NOT NULL,
	[FlowIdOld] [int] NULL,
	[FlowName] [nvarchar] (200) NOT NULL,
	[FlowType] [int] NOT NULL,
	[FormName] nvarchar(200) NOT NULL,
	[FormLanguage] [ntext] NULL,
	[FormModel] [ntext] NULL,
	[FormSetting] [ntext] NULL,
	[FormCssPdf] [ntext] NULL,
	[FormHeaderPdf] [ntext] NULL,
	[FormFooterPdf] [ntext] NULL,
	[FormCssHtml] [ntext] NULL,
	[FormCssDocx] [ntext] NULL,
	[FormName2] nvarchar(200) NULL,
	[FormLanguage2] [ntext] NULL,
	[FormModel2] [ntext] NULL,
	[FormSetting2] [ntext] NULL,
	[FormCssPdf2] [ntext] NULL,
	[FormHeaderPdf2] [ntext] NULL,
	[FormFooterPdf2] [ntext] NULL,
	[FormCssHtml2] [ntext] NULL,
	[FormCssDocx2] [ntext] NULL,
	[FormName3] nvarchar(200) NULL,
	[FormLanguage3] [ntext] NULL,
	[FormModel3] [ntext] NULL,
	[FormSetting3] [ntext] NULL,
	[FormCssPdf3] [ntext] NULL,
	[FormHeaderPdf3] [ntext] NULL,
	[FormFooterPdf3] [ntext] NULL,
	[FormCssHtml3] [ntext] NULL,
	[FormCssDocx3] [ntext] NULL,
	[BeginUser] [nvarchar] (50) NOT NULL,
	[BeginUserName] [nvarchar] (100) NOT NULL,
	[BeginDeptName] [ntext] NULL,
	[RunTime] [datetime] NOT NULL CONSTRAINT [DF_Flow_Run_RunTime] DEFAULT (getdate()),
	[EndTime] [datetime] NULL,
	[RunIp] [nvarchar] (50) NULL,
	[AttachmentId] [nvarchar] (50) NULL,
	[Status] [int] NOT NULL CONSTRAINT [DF_Flow_Run_Status] DEFAULT (0),
	[DelFlag] [int] NOT NULL CONSTRAINT [DF_Flow_Run_DelFlag] DEFAULT (0),
	[TeamId] [bigint] NULL,
	[ArchiveTime] [datetime] NULL,
	CONSTRAINT [PK_Flow_Run] PRIMARY KEY  CLUSTERED 
	(
		[RunId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Run_Data] (
	[DataId] [bigint] IDENTITY (1, 1) NOT NULL,
	[RunId] [bigint] NOT NULL,
	[ItemId] [nvarchar] (20) NOT NULL,
	[ItemData] [ntext] NULL,
	[ItemPrcsId] [int] NULL,
	[ItemPrcsName] [nvarchar] (200) NULL,
	[ItemUserId] [nvarchar] (50) NULL,
	[ItemUserName] [nvarchar] (100) NULL,
	[ItemDeptName] [ntext] NULL,
	[ItemIp] [nvarchar] (50) NULL,
	[ItemTime] [datetime] NULL,
	CONSTRAINT [PK_Flow_Run_Data] PRIMARY KEY  CLUSTERED 
	(
		[DataId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Run_Comment] (
	[CommentId] [bigint] IDENTITY (1, 1) NOT NULL,
	[RunId] [bigint] NOT NULL,
	[PrcsId] [int] NOT NULL,
	[PrcsName] [nvarchar] (200) NULL,
	[FlowPrcs] [int] NOT NULL,
	[UserId] [nvarchar] (50) NOT NULL,
	[UserName] [nvarchar] (100) NOT NULL,
	[DeptName] [ntext] NULL,
	[CommentContent] [ntext] NULL,
	[AttachmentId] [nvarchar] (50) NULL,
	[EditTime] [datetime] NOT NULL CONSTRAINT [DF_Flow_Run_Comment_EditTime] DEFAULT (getdate()),
	[CommentIp] [nvarchar] (50) NULL,
	CONSTRAINT [PK_Flow_Run_Comment] PRIMARY KEY  CLUSTERED 
	(
		[CommentId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Run_Forms] (
	[FormsId] [bigint] IDENTITY(1,1) NOT NULL,
	[RunId] [bigint] NOT NULL,
	[PrcsId] [int] NOT NULL,
	[FlowPrcs] [int] NOT NULL,
	[AttachmentId] [nvarchar](50) NULL,
	[FullName] [nvarchar](50) NULL,
	[Mobile] [nvarchar](20) NULL,
	[Email] [nvarchar](200) NULL,
	[SubmitIp] [nvarchar](50) NULL,
	[SubmitTime] [datetime] NOT NULL CONSTRAINT [DF_Flow_Run_Forms_SubmitTime]  DEFAULT (getdate()),
	CONSTRAINT [PK_Flow_Run_Forms] PRIMARY KEY  CLUSTERED 
	(
		[FormsId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Run_Prcs] (
	[RunPrcsId] [bigint] IDENTITY (1, 1) NOT NULL,
	[RunId] [bigint] NOT NULL CONSTRAINT [DF_Flow_Run_Prcs_RunId] DEFAULT (0) ,
	[PrcsId] [int] NOT NULL CONSTRAINT [DF_Flow_Run_Prcs_PrcsId] DEFAULT (0) ,
	[PrcsName] [nvarchar] (200) NULL,
	[FlowPrcs] [int] NOT NULL CONSTRAINT [DF_Flow_Run_Prcs_FlowPrcs] DEFAULT (0) ,
	[HiddenItem] [ntext] NULL,
	[FormsRandom] [nvarchar] (50) NULL,
	[FormsPassword] [nvarchar] (50) NULL,
	[UserId] [nvarchar] (50) NOT NULL,
	[UserName] [nvarchar] (100) NOT NULL,
	[DeptName] [ntext] NULL,
	[PrcsTime] [datetime] NULL,
	[DeliverTime] [datetime] NULL,
	[PrcsFlag] [int] NOT NULL CONSTRAINT [DF_Flow_Run_Prcs_PrcsFlag] DEFAULT (1) ,
	[HostFlag] [int] NOT NULL CONSTRAINT [DF_Flow_Run_Prcs_HostFlag] DEFAULT (1) ,
	[TopFlag] [int] NOT NULL CONSTRAINT [DF_Flow_Run_Prcs_TopFlag] DEFAULT (0) ,
	[RuleUser] [nvarchar] (50) NULL,
	[RuleUserName] [nvarchar] (100) NULL,
	[RuleDeptName] [ntext] NULL,
	[RuleTime] [datetime] NULL,
	[PrcsIp] [nvarchar] (50) NULL,
	[TimeOut] [int] NULL,
	CONSTRAINT [PK_Flow_Run_Prcs] PRIMARY KEY  CLUSTERED 
	(
		[RunPrcsId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Sign] (
	[SignId] [int] IDENTITY (1, 1) NOT NULL,
	[SignNo] [int] NOT NULL,
	[SignType] [nvarchar] (20) NULL,
	[SignName] [nvarchar] (50) NOT NULL,
	[PrivUser] [nvarchar] (800) NULL,
	[SignData] [ntext] NOT NULL,
	[SignPassword] [nvarchar] (200) NULL,
	[AddTime] [datetime] NOT NULL CONSTRAINT [DF_Flow_Sign_AddTime] DEFAULT (getdate()),
	CONSTRAINT [PK_Flow_Sign] PRIMARY KEY  CLUSTERED 
	(
		[SignId]
	)
)
GO

CREATE TABLE [dbo].[Flow_Sort] (
	[SortId] [int] IDENTITY (1, 1) NOT NULL,
	[SortNo] [int] NOT NULL CONSTRAINT [DF_Flow_Sort_SortNo] DEFAULT (0),
	[SortName] [nvarchar] (200) NOT NULL,
	[DelFlag] [int] NOT NULL CONSTRAINT [DF_Flow_Sort_DelFlag] DEFAULT (0),
	CONSTRAINT [PK_Flow_Sort] PRIMARY KEY  CLUSTERED 
	(
		[SortId]
	)
)
GO

CREATE TABLE [dbo].[Sys_Notification](
	[NotificationId] [bigint] IDENTITY(1,1) NOT NULL,
	[NotificationGuid] [uniqueidentifier] NOT NULL CONSTRAINT [DF_Sys_Notification_NotificationGuid] DEFAULT (NEWSEQUENTIALID()),	
	[FromUserId] [nvarchar](50) NOT NULL,
	[FromUserName] [nvarchar](100) NOT NULL,
	[FromDeptName] [ntext] NULL,
	[ToUserId] [nvarchar](50) NOT NULL,
	[ToUserName] [nvarchar](50) NOT NULL,
	[ToDeptName] [ntext] NULL,
	[ToEmail] [nvarchar](200) NULL,
	[ToEmailDone] [int] NULL,
	[NotificationType] nvarchar(50) NULL,
	[NotificationContent] [ntext] NOT NULL,
	[NotificationParameter] [ntext] NULL,
	[NotificationTime] [datetime] NOT NULL CONSTRAINT [DF_Sys_Notification_NotificationTime]  DEFAULT (getdate()),
	[NotificationUrl] [ntext] NULL,
	[WorkflowRunId] [bigint] NULL,
	[RelatedId] [bigint] NULL,
	[OfficialDocId] [bigint] NULL,
	[RemindFlag] [bit] NOT NULL CONSTRAINT [DF_Sys_Notification_RemindFlag]  DEFAULT ((1)),
	[ExtensionFlags] [int] NULL,
	CONSTRAINT [PK_Sys_Notification] PRIMARY KEY CLUSTERED 
	(
		[NotificationId] ASC
	)
)
GO

CREATE TABLE [dbo].[Sys_SmsCode](
	[SmsId] [int] IDENTITY(1,1) NOT NULL,
	[MobileNumber] [nvarchar](20) NOT NULL,
	[SmsCode] [nvarchar](10) NOT NULL,
	[RequestTime] [datetime] NOT NULL CONSTRAINT [DF_Sys_SmsCode_RequestTime]  DEFAULT (getdate()),
	[RequestIp] [nvarchar](50) NULL,
	[IsExpired] bit NOT NULL CONSTRAINT [DF_Sys_SmsCode_IsExpired]  DEFAULT ((0)),
	CONSTRAINT [PK_Sys_SmsCode] PRIMARY KEY CLUSTERED 
	(
		[SmsId] ASC
	)
)
GO

CREATE TABLE [dbo].[Sys_Cache] (
	[ParaId] [int] IDENTITY (1, 1) NOT NULL,
	[ParaName] [nvarchar] (200) NOT NULL,
	[ParaValue] [ntext] NULL,
	[ParaImage] [image] NULL,
	CONSTRAINT [PK_Sys_Cache] PRIMARY KEY  CLUSTERED 
	(
		[ParaId]
	)
)
GO

CREATE TABLE [dbo].[Sys_Function] (
	[FuncId] [int] IDENTITY (1, 1) NOT NULL,
	[MenuId] [nvarchar] (50) NOT NULL,
	[FuncName] [nvarchar] (100) NOT NULL,
	[FuncCode] [nvarchar] (200) NOT NULL,
	[FuncUrl] [ntext] NULL,
	[NewTarget] [bit] NOT NULL CONSTRAINT [DF_Sys_Function_NewTarget] DEFAULT ((0)),
	CONSTRAINT [PK_Sys_Function] PRIMARY KEY  CLUSTERED 
	(
		[FuncCode]
	)
)
GO

CREATE TABLE [dbo].[Sys_HomeControls] (
	[ControlId] [int] IDENTITY (1, 1) NOT NULL,
	[ControlNo] [nvarchar] (10) NOT NULL,
	[ControlName] [nvarchar] (50) NOT NULL,
	[ControlPos] [nvarchar] (2) NOT NULL CONSTRAINT [DF_Sys_HomeControls_ControlPos] DEFAULT ('l'),
	[ControlPath] [nvarchar] (200) NULL,
	[ControlHtmlCode] [ntext] NULL,
	[CallStoredProcedure] [nvarchar] (200) NULL,
	[ByFuncCode] [nvarchar] (200) NULL,
	[ByUserId] [ntext] NULL,
	[IsDisplay] [bit] NOT NULL CONSTRAINT [DF_Sys_HomeControls_IsDisplay] DEFAULT ((1)), 
	CONSTRAINT [PK_Sys_HomeControls] PRIMARY KEY  CLUSTERED 
	(
		[ControlId]
	)
)
GO

CREATE TABLE [dbo].[Sys_Log] (
	[LogId] [bigint] IDENTITY (1, 1) NOT NULL,
	[LogType] [nvarchar] (50) NULL,
	[UserId] [nvarchar] (200) NULL,
	[UserName] [nvarchar] (100) NULL,
	[DeptName] [ntext] NULL,
	[LogTime] [datetime] NULL CONSTRAINT [DF_Sys_Log_LogTime] DEFAULT (getdate()),
	[Ip] [nvarchar] (50) NULL,
	[Remark] [ntext] NULL,
	CONSTRAINT [PK_Sys_Log] PRIMARY KEY  CLUSTERED 
	(
		[LogId]
	)
)
GO

CREATE TABLE [dbo].[Sys_Menu] (
	[MenuId] [nvarchar] (50) NOT NULL,
	[MenuName] [nvarchar] (100) NOT NULL,
	CONSTRAINT [PK_Sys_Menu] PRIMARY KEY  CLUSTERED 
	(
		[MenuId]
	)
)
GO

CREATE TABLE [dbo].[Sys_Org] (
	[Name] [ntext] NULL,
	[Address] [ntext] NULL,
	[PostCode] [nvarchar] (10) NULL,
	[TelNo] [nvarchar] (100) NULL,	
	[SiteUrl] [ntext] NULL,
	[Email] [ntext] NULL,
	[MoreInfo] [ntext] NULL
)
GO

CREATE TABLE [dbo].[User_Role] (
	[RoleId] [int] IDENTITY (1, 1) NOT NULL,
	[RoleNo] [int] NOT NULL CONSTRAINT [DF_User_Role_RoleNo] DEFAULT (10),
	[RoleName] [nvarchar] (50) NOT NULL,
	[RoleIdString] [ntext] NULL,
	CONSTRAINT [PK_User_Role] PRIMARY KEY  CLUSTERED 
	(
		[RoleId]
	)
)
GO

CREATE TABLE [dbo].[Users] (
	[Id] [int] IDENTITY (1, 1) NOT NULL,
	[UserId] [nvarchar] (50) NOT NULL,
	[UserNo] [int] NULL CONSTRAINT [DF_Users_UserNo] DEFAULT ((10)),
	[UserGuid] [uniqueidentifier] NULL CONSTRAINT [DF_Users_UserGuid] DEFAULT (NEWSEQUENTIALID()),
	[UserName] [nvarchar] (100) NOT NULL,
	[Password] [nvarchar] (200) NULL,
	[RoleId] [int] NOT NULL CONSTRAINT [DF_Users_RoleId] DEFAULT ((0)),
	[DeptId] [int] NOT NULL CONSTRAINT [DF_Users_DeptId] DEFAULT ((0)),
	[Position] [nvarchar] (100) NULL,
	[SecureMobile] [nvarchar] (50) NULL,
	[Disabled] [bit] NOT NULL CONSTRAINT [DF_Users_Disabled] DEFAULT ((0)),
	[BindIp] [ntext] NULL,	
	[State] [int] NOT NULL CONSTRAINT [DF_Users_State] DEFAULT ((0)),
	[LastPassTime] [datetime] NULL,
	[LastChangePass] [datetime] NULL,
	[EmailCapacity] [int] NULL CONSTRAINT [DF_Users_EmailCapacity] DEFAULT ((-1)),
	[PhotoAvatar] [ntext] NULL,
	[Sex] [int] NOT NULL CONSTRAINT [DF_Users_Sex] DEFAULT ((1)),
	[Mobile] [nvarchar] (20) NULL,
	[IsHideMobile] [bit] NOT NULL CONSTRAINT [DF_Users_IsHideMobile] DEFAULT ((0)),
	[TelDept] [nvarchar] (50) NULL,
	[Email] [nvarchar] (200) NULL,
	[LinkedIn] ntext NULL,
	[WhatsApp] ntext NULL,
	[Messenger] ntext NULL,
	[Teams] ntext NULL,
	[Skype] ntext NULL,
	[WeChat] ntext NULL,	
	[Theme] [nvarchar] (20) NULL,
	[DefaultMenu] [nvarchar] (10) NULL,
	[NavbarView] [int] NOT NULL CONSTRAINT [DF_Users_NavbarView] DEFAULT ((1)),
	[NotificationAutoPop] [bit] NOT NULL CONSTRAINT [DF_Users_NotificationAutoPop] DEFAULT ((1)),
	[EsignColor] [nvarchar] (10) NULL,
	[EsignTipSize] [nvarchar] (10) NULL,
	[Culture] [nvarchar](10) NULL,
	[CredentialOptions] [ntext] NULL,
	[MoreOptions] [ntext] NULL,
	[Remark] [ntext] NULL,
	CONSTRAINT [PK_Users] PRIMARY KEY  CLUSTERED 
	(
		[UserId]
	)
)
GO

CREATE TABLE [dbo].[User_Token]
(
	[TokenId] [bigint] IDENTITY(1,1) NOT NULL,
	[TokenGuid] [uniqueidentifier] NOT NULL CONSTRAINT [DF_User_Token_TokenGuid] DEFAULT (NEWSEQUENTIALID()),
	[TokenRandom] [nvarchar](50) NULL,
	[TokenName] [nvarchar](50) NOT NULL,
	[TokenUserId] [nvarchar](50) NOT NULL,
	[RunId] [bigint] NULL,
	[RunData] [nvarchar](50) NULL,
	[ReturnUrl] [ntext] NULL,
	[ValidTimeFrom] [datetime] NOT NULL,
	[ValidTimeTo] [datetime] NOT NULL,
	[UsedTime] [datetime] NULL,
	[UsedIp] [nvarchar](50) NULL,
	CONSTRAINT [PK_User_Token] PRIMARY KEY CLUSTERED 
	(
		[TokenId]
	)
)
GO

CREATE TABLE [dbo].[User_Para]
(
	[ParaId] [int] IDENTITY(1,1) NOT NULL,
	[ParaUserId] [nvarchar](50) NULL,
	[ParaName] [nvarchar](200) NOT NULL,
	[ParaValue] [ntext] NULL,	
	[ParaTime] [datetime] NOT NULL CONSTRAINT [DF_User_Para_ParaTime] DEFAULT (getdate()),
	CONSTRAINT [PK_User_Para] PRIMARY KEY CLUSTERED 
	(
		[ParaId]
	)
)
GO

CREATE TABLE [dbo].[User_Scope](
	[ScopeId] [int] IDENTITY(1,1) NOT NULL,
	[UserId] [nvarchar](50) NOT NULL,
	[ScopeType] [nvarchar](50) NULL,
	[ScopeDepartments] [ntext] NULL,
	[ScopeUsers] [ntext] NULL,
	[ScopeRoles] [ntext] NULL,
	CONSTRAINT [PK_User_Scope] PRIMARY KEY CLUSTERED 
	(
		[ScopeId] ASC
	)
)
GO

CREATE TABLE [dbo].[Sys_Para] (
	[ParaId] [int] IDENTITY (1, 1) NOT NULL,
	[ParaName] [nvarchar] (200) NOT NULL,
	[ParaValue] [ntext] NULL,
	[Remark] [nvarchar] (20) NULL,
	CONSTRAINT [PK_Sys_Para] PRIMARY KEY  CLUSTERED 
	(
		[ParaName]
	)
)
GO

SET IDENTITY_INSERT [dbo].[Department] ON

INSERT INTO [dbo].[Department] ([DeptId],[ParentDept],[DeptNo],[DeptName])
	VALUES (1,0,1,'缺省部门')
GO

SET IDENTITY_INSERT [dbo].[Department] OFF
GO

INSERT INTO [dbo].[User_Role] ([RoleNo],[RoleName],[RoleIdString])
	VALUES (1,'超级管理员',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/flow/monitor/,/flow/recover/,/flow/archiving/,/flow/form/,/flow/type/,/flow/config/sort/,/flow/config/option/,/flow/config/entrust/,/flow/config/openforms/,/flow/config/esign/,/flow/config/stamp/,/office/email/,/office/team/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,/office/mgmt/ancmt/,/office/mgmt/news/,@system,/system/org/,/system/dept/,/system/user/,/system/role/,/system/appearance/,/system/connector/,/system/menu/,/system/security/,/system/log/,/system/storage/,/system/developer/,/system/info/,')
GO

INSERT INTO [dbo].[User_Role] ([RoleNo],[RoleName],[RoleIdString])
	VALUES (2,'总经理',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/flow/monitor/,/office/email/,/office/team/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,/office/mgmt/ancmt/,/office/mgmt/news/,')
GO

INSERT INTO [dbo].[User_Role] ([RoleNo],[RoleName],[RoleIdString])
	VALUES (3,'员工',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/office/email/,/office/team/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,')
GO

INSERT INTO [dbo].[Users] ([UserId],[UserName],[Password],[RoleId],[DeptId])
	VALUES ('admin','Administrator','CF83E1357EEFB8BDF1542850D66D8007D620E4050B5715DC83F4A921D36CE9CE47D0D13C5D85F2B0FF8318D2877EEC2F63B931BD47417A81A538327AF927DA3E',1,1)
GO


CREATE NONCLUSTERED INDEX IDX_Flow_Type_NewUser ON Flow_Type(NewUser)
GO

CREATE NONCLUSTERED INDEX IDX_Flow_Type_NewDept ON Flow_Type(NewDept)
GO

CREATE NONCLUSTERED INDEX IDX_Flow_Type_ManageUser ON Flow_Type(ManageUser)
GO

CREATE NONCLUSTERED INDEX IDX_Flow_Type_QueryUser ON Flow_Type(QueryUser)
GO

CREATE NONCLUSTERED INDEX IDX_Flow_Run_RunName ON Flow_Run(RunName)
GO

CREATE NONCLUSTERED INDEX IDX_Flow_Run_Prcs_FormsRandom ON Flow_Run_Prcs(FormsRandom)
GO

CREATE NONCLUSTERED INDEX IDX_Flow_Files_Name ON Flow_Files(Name)
GO

CREATE NONCLUSTERED INDEX IDX_Office_Files_Name ON Office_Files(Name)
GO

CREATE NONCLUSTERED INDEX IDX_Team_Work_ToId ON Team_Work(ToId)
GO
