CREATE EXTENSION IF NOT EXISTS "uuid-ossp";

CREATE TABLE Office_Calendar(
	EventId BIGSERIAL PRIMARY KEY,
	EventType varchar(50) NULL,
	EventTitle varchar(200) NOT NULL,
	EventLocation varchar(50) NULL,
	EventDescription text NULL,
	UserId varchar(50) NOT NULL,
	UserName varchar(100) NOT NULL,
	DeptName text NOT NULL,
	StartTime timestamp NOT NULL,
	EndTime timestamp NULL,
	IsAllDay bool NOT NULL CONSTRAINT DF_Office_Calendar_IsAllDay DEFAULT false,
	RecurrenceRule text NULL,
	AttachmentId varchar(50) NULL,
	AddTime timestamp NOT NULL CONSTRAINT DF_Office_Calendar_AddTime DEFAULT now(),
	ManagerUserId varchar(50) NULL,
	ManagerUserName varchar(100) NULL,
	ManagerDeptName text NULL,
	ManagerAttachmentId varchar(50) NULL,
	ManagerSubmitDescription text NULL,
	ManagerSubmitTime timestamp NULL
);

CREATE TABLE Office_Email (
	EmailId BIGSERIAL PRIMARY KEY,
	FromId varchar (50) NOT NULL,
	FromUserName varchar (100) NOT NULL,
	FromDeptName text NULL,
	ToId varchar (50) NULL,
	ToUserName varchar (100) NULL,
	ToDeptName text NULL,
	ToIds text NULL,
	Subject varchar (200) NOT NULL,
	EmailContent text NULL,
	SendTime timestamp NOT NULL CONSTRAINT DF_Office_Email_SendTime DEFAULT now(),
	AttachmentId varchar (50) NULL,
	ReadFlag boolean NOT NULL CONSTRAINT DF_Office_Email_ReadFlag DEFAULT false,
	DeleteFlag int NOT NULL CONSTRAINT DF_Office_Email_DeleteFlag DEFAULT (0),
	TotalSize int NOT NULL CONSTRAINT DF_Office_Email_TotalSize DEFAULT (0),
	Important int NOT NULL CONSTRAINT DF_Office_Email_Important DEFAULT (0)
);

CREATE TABLE Office_Announcement (
	AnnouncementId BIGSERIAL PRIMARY KEY,
	UserId varchar (50) NOT NULL,
	UserName varchar (100) NOT NULL,
	DeptName text NULL,
	ToId varchar (800) NULL,
	ToUser varchar (800) NULL,
	Subject varchar (200) NOT NULL,
	AnnouncementContent text NULL,
	SendTime timestamp NOT NULL CONSTRAINT DF_Office_Announcement_SendTime DEFAULT now(),
	BeginDate timestamp NULL,
	EndDate timestamp NULL,
	AttachmentId varchar (50) NULL,
	Important boolean NOT NULL CONSTRAINT DF_Office_Announcement_Important DEFAULT false,	
	ViewCount int NULL,
	CommentCount int NOT NULL CONSTRAINT DF_Office_Announcement_CommentCount DEFAULT (0),
	Readers text NULL
);

CREATE TABLE Office_Announcement_Comment (
	CommentId BIGSERIAL PRIMARY KEY,
	AnnouncementId bigint NOT NULL,
	UserId varchar (50) NOT NULL,
	UserName varchar (100) NOT NULL,
	DeptName text NULL,
	CommentContent text NULL,
	ReplyTime timestamp NOT NULL CONSTRAINT DF_Office_Announcement_Comment_ReplyTime DEFAULT now()
);

CREATE TABLE Office_News (
	NewsId BIGSERIAL PRIMARY KEY,
	UserId varchar (50) NOT NULL,
	UserName varchar (100) NOT NULL,
	DeptName text NULL,
	ToId varchar (4000) NULL,
	ToUser varchar (4000) NULL,
	Subject varchar (200) NOT NULL,
	NewsContent text NULL,
	SendTime timestamp NOT NULL CONSTRAINT DF_Office_News_SendTime DEFAULT now(),
	AttachmentId varchar (50) NULL,
	ViewCount int NOT NULL CONSTRAINT DF_Office_News_ViewCount DEFAULT (0),
	CommentCount int NOT NULL CONSTRAINT DF_Office_News_CommentCount DEFAULT (0),
	Readers text NULL
);

CREATE TABLE Office_News_Comment (
	CommentId BIGSERIAL PRIMARY KEY,
	NewsId bigint NOT NULL,
	UserId varchar (50) NOT NULL,
	UserName varchar (100) NOT NULL,
	DeptName text NULL,
	CommentContent text NULL,
	ReplyTime timestamp NOT NULL CONSTRAINT DF_Office_News_Comment_ReplyTime DEFAULT now()
);

CREATE TABLE Office_WorkReport(
	ReportId BIGSERIAL PRIMARY KEY,
	FromUserId varchar(50) NOT NULL,
	FromUserName varchar(100) NOT NULL,
	FromDeptName text NULL,
	ToUserId varchar(50) NULL,
	ToUserName varchar(100) NULL,
	ToDeptName text NULL,
	ReportTitle varchar(200) NOT NULL,
	ReportType varchar(100) NOT NULL,
	ReportContent text NULL,
	ReportTime timestamp NOT NULL CONSTRAINT DF_Office_WorkReport_ReportTime  DEFAULT now(),
	AttachmentId varchar(50) NULL,
	CommentContent text NULL,
	CommentTime timestamp NULL,
	ReadFlag bool NOT NULL CONSTRAINT DF_Office_WorkReport_ReadFlag  DEFAULT false,
	Important bool NOT NULL CONSTRAINT DF_Office_WorkReport_Important  DEFAULT false,
	DeleteFlag int NOT NULL CONSTRAINT DF_Office_WorkReport_DeleteFlag  DEFAULT (0)
);

CREATE TABLE Office_Wordpad (
	WordId BIGSERIAL PRIMARY KEY,
	UserId varchar(50) NOT NULL,
	WordSubject varchar(500) NOT NULL,
	WordContent text NOT NULL,
	WordAttachmentId varchar (50) NULL,
	MoreOptions text NULL,
	WordTime timestamp NOT NULL CONSTRAINT DF_Office_Wordpad_WordTime DEFAULT now()
);

CREATE TABLE Office_Files (
	AttachId BIGSERIAL PRIMARY KEY,
	AttachType varchar (50)  NOT NULL,
	AttachmentId varchar (50) NOT NULL,
	Name varchar (200) NOT NULL,	
	UserId varchar (50) NULL,
	UserName varchar (100) NULL,
	DeptName text NULL,
	AddTime timestamp NOT NULL CONSTRAINT DF_Office_Files_AddTime DEFAULT now(),
	AddIp varchar (50) NULL,
	ContentType varchar (200) NULL,
	ContentLength bigint NOT NULL CONSTRAINT DF_Office_Files_ContentLength DEFAULT (0),	
	Guid uuid NULL CONSTRAINT DF_Office_Files_Guid DEFAULT uuid_generate_v1(),
	DeleteFlag boolean NOT NULL CONSTRAINT DF_Office_Files_DeleteFlag DEFAULT false
);

CREATE TABLE Team_Work (
	TeamId BIGSERIAL PRIMARY KEY,
	Name varchar (200) NOT NULL,
	WorkContent text NULL,
	ToId varchar (800) NULL,
	Participator varchar (800) NULL,
	Manager varchar (800) NULL,
	AttachmentId varchar (50) NULL,
	FileAttachmentId varchar (50) NULL,
	CompletedPercent int NOT NULL CONSTRAINT DF_Team_Work_CompletedPercent DEFAULT (0),
	Status int NOT NULL,
	CreateDate timestamp NOT NULL CONSTRAINT DF_Team_Work_CreateDate DEFAULT now(),
	Creator varchar (50) NOT NULL,
	CreatorUserName varchar (100) NOT NULL,
	CreatorDeptName text NULL 
);

CREATE TABLE Team_Comment (
	CommentId BIGSERIAL PRIMARY KEY,
	CommentGuid uuid NOT NULL CONSTRAINT DF_Team_Comment_CommentGuid  DEFAULT uuid_generate_v1(),
	ParentGuid uuid NULL,
	TeamId bigint NOT NULL,
	CommentTime timestamp NOT NULL CONSTRAINT DF_Team_Comment_CommentTime DEFAULT now(),
	CommentContent text NOT NULL,
	AttachmentId varchar(50) NULL,
	CommentUserId varchar(50) NULL,
	CommentUserName varchar (100) NOT NULL,
	CommentDeptName text NULL
);

CREATE TABLE Team_Log (
	LogId BIGSERIAL PRIMARY KEY,
	TeamId bigint NOT NULL,
	LogTime timestamp NOT NULL CONSTRAINT DF_Team_Log_LogTime DEFAULT now(),
	Progress varchar (50) NULL,
	LogContent text NULL,
	AttachmentId varchar (50) NULL,
	LogUserId varchar (50) NOT NULL,
	LogUserName varchar (100) NOT NULL,
	LogDeptName text NULL
);

CREATE TABLE Department (
	DeptId SERIAL PRIMARY KEY,
	DeptNo int NOT NULL CONSTRAINT DF_Department_DeptNo DEFAULT (10),	
	ParentDept int NOT NULL CONSTRAINT DF_Department_ParentDept DEFAULT (0),
	DeptName varchar (200) NOT NULL,	
	Manager varchar (100) NULL,
	Leader varchar (100) NULL,
	TelNo varchar (50) NULL,
	DeptFunc text NULL
);

CREATE TABLE Flow_Files (
	AttachId BIGSERIAL PRIMARY KEY,
	AttachType varchar (50)  NOT NULL,
	AttachmentId varchar (50) NOT NULL,
	Name varchar (200) NOT NULL,	
	UserId varchar (50) NULL,
	UserName varchar (100) NULL,
	DeptName text NULL,
	AddTime timestamp NOT NULL CONSTRAINT DF_Flow_Files_AddTime DEFAULT now(),
	AddIp varchar (50) NULL,
	AddRemark text NULL,
	ContentType varchar (200) NULL,
	ContentLength bigint NOT NULL CONSTRAINT DF_Flow_Files_ContentLength DEFAULT (0),	
	Guid uuid NULL CONSTRAINT DF_Flow_Files_Guid DEFAULT uuid_generate_v1(),
	DeleteFlag boolean NOT NULL CONSTRAINT DF_Flow_Files_DeleteFlag DEFAULT false
);

CREATE TABLE Flow_Form (
	FormId SERIAL PRIMARY KEY,
	FormName varchar(200) NOT NULL,
	FormLanguage text NULL,
	FormLabel varchar(50) NULL,
	FormRemark text NULL,
	FormModel text NULL,
	FormSetting text NULL,
	FormScript text NULL,
	CssPdf text NULL,
	HeaderPdf text NULL,
	FooterPdf text NULL,
	CssHtml text NULL,
	CssDocx text NULL,
	DelFlag int NOT NULL CONSTRAINT DF_Flow_Form_DelFlag DEFAULT (0),
	IsSeal boolean NOT NULL CONSTRAINT DF_Flow_Form_IsSeal DEFAULT false
);

CREATE TABLE Flow_Type (
	FlowId SERIAL PRIMARY KEY,
	FlowSort int NOT NULL CONSTRAINT DF_Flow_Type_FlowSort DEFAULT (0),
	FlowNo int NOT NULL CONSTRAINT DF_Flow_Type_FlowNo DEFAULT (1),
	FlowName varchar (200) NOT NULL,	
	FlowType int NOT NULL,
	FormId int NULL,
	FormId2 int NULL,
	FormId3 int NULL,
	RuleOther int NOT NULL CONSTRAINT DF_Flow_Type_RuleOther DEFAULT (2),
	FlowDoc boolean NOT NULL CONSTRAINT DF_Flow_Type_FlowDoc DEFAULT false,
	NewUser varchar (800) NULL,
	NewDept varchar (800) NULL CONSTRAINT DF_Flow_Type_NewDept DEFAULT (N'ALL_DEPT'),
	ManageUser varchar (800) NULL,
	QueryUser varchar (800) NULL,
	AutoName text NULL,
	AutoCounter bigint NOT NULL CONSTRAINT DF_Flow_Type_AutoCounter DEFAULT (0),
	AutoLen int NOT NULL CONSTRAINT DF_Flow_Type_AutoLen DEFAULT (0),
	AutoEdit int NOT NULL CONSTRAINT DF_Flow_Type_AutoEdit DEFAULT (0),
	TitleItem text NULL,
	QueryItem text NULL,
	QueryExcel boolean NOT NULL CONSTRAINT DF_Flow_Type_QueryExcel DEFAULT true,
	DocxSplitPrint boolean NOT NULL CONSTRAINT DF_Flow_Type_DocxSplitPrint DEFAULT true,
	PdfSplitPrint boolean NOT NULL CONSTRAINT DF_Flow_Type_PdfSplitPrint DEFAULT true,
	PrintTemplate varchar(200) NULL CONSTRAINT DF_Flow_Type_PrintTemplate DEFAULT (N'Signature,Attach,Comment,Diagram'),
	DelFlag int NOT NULL CONSTRAINT DF_Flow_Type_DelFlag DEFAULT (0),
	FlowDesc text NULL
);

CREATE TABLE Flow_Process (
	ProcessId SERIAL PRIMARY KEY,
	FlowId int NOT NULL,
	PrcsId int NOT NULL CONSTRAINT DF_Flow_Process_PrcsId DEFAULT (0),
	PrcsName varchar (200) NOT NULL,
	PrcsGuid uuid NOT NULL CONSTRAINT DF_Flow_Process_PrcsGuid  DEFAULT uuid_generate_v1(),
	FormsTitle varchar(100) NULL,
	FormsId int NULL,
	FormsVerifyType varchar(20) NULL,
	FormsBeginUser text NULL,
	FormsRandom varchar(50) NULL,
	FormsPassword varchar(50) NULL,
	FormsAttach boolean NOT NULL CONSTRAINT DF_FormsAttach DEFAULT false,
	FormsEmail varchar(200),
	FormsLanguage varchar(20),
	PrcsItem text NULL,
	AutoItem text NULL,
	HiddenItem text NULL,
	PrcsUser varchar (800) NULL,
	PrcsDept varchar (800) NULL CONSTRAINT DF_Flow_Process_PrcsDept DEFAULT (N'ALL_DEPT'),
	PrcsTo text NULL,
	SetLeft int NOT NULL CONSTRAINT DF_Flow_Process_SetLeft DEFAULT (0),
	SetTop int NOT NULL CONSTRAINT DF_Flow_Process_SetTop DEFAULT (0),	
	ConditionIn text NULL,
	ConditionInFormula text NULL,
	ConditionOut text NULL,	
	ConditionOutFormula text NULL,
	ConditionDesc text NULL,
	Comment int NOT NULL CONSTRAINT DF_Flow_Process_Comment DEFAULT (0),
	TurnPriv int NOT NULL CONSTRAINT DF_Flow_Process_TurnPriv DEFAULT (1),
	UserFilter int NOT NULL CONSTRAINT DF_Flow_Process_UserFilter DEFAULT (0),
	AutoType int NOT NULL CONSTRAINT DF_Flow_Process_AutoType DEFAULT (0),
	UserLock int NOT NULL CONSTRAINT DF_Flow_Process_UserLock DEFAULT (0),
	TopDefault boolean NOT NULL CONSTRAINT DF_Flow_Process_TopDefault DEFAULT false,
	AutoUserOp varchar (50) NULL,
	AutoUser varchar (800) NULL,	
	AllowBack int NOT NULL CONSTRAINT DF_Flow_Process_AllowBack DEFAULT (0),
	TimeOut int NULL,
	AttachPriv varchar (50) NULL CONSTRAINT DF_Flow_Process_AttachPriv DEFAULT (N'new,del,')
);

CREATE TABLE Flow_Rule (
	RuleId SERIAL PRIMARY KEY,
	FlowId int NULL,
	UserId varchar (50) NOT NULL,
	ToId varchar (50) NOT NULL,
	BeginDate timestamp NULL,
	EndDate timestamp NULL  
);

CREATE TABLE Flow_Run (
	RunId BIGSERIAL PRIMARY KEY,
	RunGuid uuid NOT NULL CONSTRAINT DF_Flow_Run_Guid DEFAULT uuid_generate_v1(),
	SubRunId bigint NULL,
	AutoCounter bigint NULL,
	RunName varchar (500) NOT NULL,
	FlowId int NOT NULL,
	FlowIdOld int NULL,
	FlowName varchar (200) NOT NULL,
	FlowType int NOT NULL,
	FormName varchar(200) NOT NULL,
	FormLanguage text NULL,
	FormModel text NULL,
	FormSetting text NULL,
	FormCssPdf text NULL,
	FormHeaderPdf text NULL,
	FormFooterPdf text NULL,
	FormCssHtml text NULL,
	FormCssDocx text NULL,
	FormName2 varchar(200) NULL,
	FormLanguage2 text NULL,
	FormModel2 text NULL,
	FormSetting2 text NULL,
	FormCssPdf2 text NULL,
	FormHeaderPdf2 text NULL,
	FormFooterPdf2 text NULL,
	FormCssHtml2 text NULL,
	FormCssDocx2 text NULL,
	FormName3 varchar(200) NULL,
	FormLanguage3 text NULL,
	FormModel3 text NULL,
	FormSetting3 text NULL,
	FormCssPdf3 text NULL,
	FormHeaderPdf3 text NULL,
	FormFooterPdf3 text NULL,
	FormCssHtml3 text NULL,
	FormCssDocx3 text NULL,
	BeginUser varchar (50) NOT NULL,
	BeginUserName varchar (100) NOT NULL,
	BeginDeptName text NULL,
	RunTime timestamp NOT NULL CONSTRAINT DF_Flow_Run_RunTime DEFAULT now(),
	EndTime timestamp NULL,
	RunIp varchar (50) NULL,
	AttachmentId varchar (50) NULL,
	Status int NOT NULL CONSTRAINT DF_Flow_Run_Status DEFAULT (0),
	DelFlag int NOT NULL CONSTRAINT DF_Flow_Run_DelFlag DEFAULT (0),
	TeamId bigint NULL,
	ArchiveTime timestamp NULL
);

CREATE TABLE Flow_Run_Data (
	DataId BIGSERIAL PRIMARY KEY,
	RunId bigint NOT NULL,
	ItemId varchar (20) NOT NULL,
	ItemData text NULL,
	ItemPrcsId int NULL,
	ItemPrcsName varchar (200) NULL,
	ItemUserId varchar (50) NULL,
	ItemUserName varchar (100) NULL,
	ItemDeptName text NULL,
	ItemIp varchar (50) NULL,
	ItemTime timestamp NULL
);


CREATE TABLE Flow_Run_Comment (
	CommentId BIGSERIAL PRIMARY KEY,
	RunId bigint NOT NULL,
	PrcsId int NOT NULL,
	PrcsName varchar (200) NULL,
	FlowPrcs int NOT NULL,
	UserId varchar (50) NOT NULL,
	UserName varchar (100) NOT NULL,
	DeptName text NULL,
	CommentContent text NULL,
	AttachmentId varchar (50) NULL,
	EditTime timestamp NOT NULL CONSTRAINT DF_Flow_Run_Comment_EditTime DEFAULT now(),
	CommentIp varchar (50) NULL
);


CREATE TABLE Flow_Run_Forms (
	FormsId BIGSERIAL PRIMARY KEY,
	RunId bigint NOT NULL,
	PrcsId int NOT NULL,
	FlowPrcs int NOT NULL,
	AttachmentId varchar(50) NULL,
	FullName varchar(50) NULL,
	Mobile varchar(20) NULL,
	Email varchar(200) NULL,
	SubmitIp varchar(50) NULL,
	SubmitTime timestamp NOT NULL CONSTRAINT DF_Flow_Run_Forms_SubmitTime  DEFAULT now()
);


CREATE TABLE Flow_Run_Prcs (
	RunPrcsId BIGSERIAL PRIMARY KEY,
	RunId bigint NOT NULL CONSTRAINT DF_Flow_Run_Prcs_RunId DEFAULT (0) ,
	PrcsId int NOT NULL CONSTRAINT DF_Flow_Run_Prcs_PrcsId DEFAULT (0) ,
	PrcsName varchar (200) NULL,
	FlowPrcs int NOT NULL CONSTRAINT DF_Flow_Run_Prcs_FlowPrcs DEFAULT (0) ,
	HiddenItem text NULL,
	FormsRandom varchar (50) NULL,
	FormsPassword varchar (50) NULL,
	UserId varchar (50) NOT NULL,
	UserName varchar (100) NOT NULL,
	DeptName text NULL,
	PrcsTime timestamp NULL,
	DeliverTime timestamp NULL,
	PrcsFlag int NOT NULL CONSTRAINT DF_Flow_Run_Prcs_PrcsFlag DEFAULT (1) ,
	HostFlag int NOT NULL CONSTRAINT DF_Flow_Run_Prcs_HostFlag DEFAULT (1) ,
	TopFlag int NOT NULL CONSTRAINT DF_Flow_Run_Prcs_TopFlag DEFAULT (0) ,
	RuleUser varchar (50) NULL,
	RuleUserName varchar (100) NULL,
	RuleDeptName text NULL,
	RuleTime timestamp NULL,
	PrcsIp varchar (50) NULL,
	TimeOut int NULL
);

CREATE TABLE Flow_Sign (
	SignId SERIAL PRIMARY KEY,
	SignNo int NOT NULL,
	SignType varchar (20) NULL,
	SignName varchar (50) NOT NULL,
	PrivUser varchar (800) NULL,
	SignData text NOT NULL,
	SignPassword varchar (200) NULL,
	AddTime timestamp NOT NULL CONSTRAINT DF_Flow_Sign_AddTime DEFAULT now()
);


CREATE TABLE Flow_Sort (
	SortId SERIAL PRIMARY KEY,
	SortNo int NOT NULL CONSTRAINT DF_Flow_Sort_SortNo DEFAULT (0),
	SortName varchar (200) NOT NULL,
	DelFlag int NOT NULL CONSTRAINT DF_Flow_Sort_DelFlag DEFAULT (0)
);

CREATE TABLE Sys_Notification (
	NotificationId BIGSERIAL PRIMARY KEY,
	NotificationGuid uuid NOT NULL CONSTRAINT DF_Sys_Notification_NotificationGuid DEFAULT uuid_generate_v1(),	
	FromUserId varchar(50) NOT NULL,
	FromUserName varchar(100) NOT NULL,
	FromDeptName text NULL,
	ToUserId varchar(50) NOT NULL,
	ToUserName varchar(50) NOT NULL,
	ToDeptName text NULL,
	ToEmail varchar(200) NULL,
	ToEmailDone int NULL,
	NotificationType varchar(50) NULL,
	NotificationContent text NOT NULL,
	NotificationParameter text NULL,
	NotificationTime timestamp NOT NULL CONSTRAINT DF_Sys_Notification_NotificationTime  DEFAULT now(),
	NotificationUrl text NULL,
	WorkflowRunId bigint NULL,
	RelatedId bigint NULL,
	OfficialDocId bigint NULL,
	RemindFlag boolean NOT NULL CONSTRAINT DF_Sys_Notification_RemindFlag  DEFAULT true,
	ExtensionFlags int NULL
);

CREATE TABLE Sys_SmsCode (
	SmsId SERIAL PRIMARY KEY,
	MobileNumber varchar(20) NOT NULL,
	SmsCode varchar(10) NOT NULL,
	RequestTime timestamp NOT NULL CONSTRAINT DF_Sys_SmsCode_RequestTime  DEFAULT now(),
	RequestIp varchar(50) NULL,
	IsExpired boolean NOT NULL CONSTRAINT DF_Sys_SmsCode_IsExpired  DEFAULT false
);

CREATE TABLE Sys_Cache (
	ParaId SERIAL PRIMARY KEY,
	ParaName varchar (200) NOT NULL,
	ParaValue text NULL,
	ParaImage bytea NULL 
);

CREATE TABLE Sys_Function (
	FuncId SERIAL PRIMARY KEY,
	MenuId varchar (50) NOT NULL,
	FuncName varchar (100) NOT NULL,
	FuncCode varchar (200) NOT NULL,
	FuncUrl text NULL,
	NewTarget boolean NOT NULL CONSTRAINT DF_Sys_Function_NewTarget DEFAULT false
);

CREATE TABLE Sys_HomeControls (
	ControlId SERIAL PRIMARY KEY,
	ControlNo varchar (10) NOT NULL,
	ControlName varchar (50) NOT NULL,
	ControlPos varchar (2) NOT NULL CONSTRAINT DF_Sys_HomeControls_ControlPos DEFAULT ('l'),
	ControlPath varchar (200) NULL,
	ControlHtmlCode text NULL,
	CallStoredProcedure varchar (200) NULL,
	ByFuncCode varchar (200) NULL,
	ByUserId text NULL,	
	IsDisplay boolean NOT NULL CONSTRAINT DF_Sys_HomeControls_IsDisplay DEFAULT true
);

CREATE TABLE Sys_Log (
	LogId BIGSERIAL PRIMARY KEY,
	LogType varchar (50) NULL,
	UserId varchar (200) NULL,
	UserName varchar (100) NULL,
	DeptName text NULL,
	LogTime timestamp NULL CONSTRAINT DF_Sys_Log_LogTime DEFAULT now(),
	Ip varchar (50) NULL,
	Remark text NULL
);

CREATE TABLE Sys_Menu (
	MenuId varchar (50) NOT NULL,
	MenuName varchar (100) NOT NULL
);

CREATE TABLE Sys_Org (
	Name text NULL,
	Address text NULL,
	PostCode varchar (10) NULL,
	TelNo varchar (100) NULL,
	SiteUrl text NULL,
	Email text NULL,
	MoreInfo text NULL
);

CREATE TABLE User_Role (
	RoleId SERIAL PRIMARY KEY,
	RoleNo int NOT NULL CONSTRAINT DF_User_Role_RoleNo DEFAULT (10),
	RoleName varchar (50) NOT NULL,
	RoleIdString text NULL
);

CREATE TABLE Users (
	Id SERIAL PRIMARY KEY,
	UserId varchar (50) NOT NULL,
	UserNo int NULL CONSTRAINT DF_Users_UserNo DEFAULT ((10)),
	UserGuid uuid NULL CONSTRAINT DF_Users_UserGuid DEFAULT uuid_generate_v1(),
	UserName varchar (100) NOT NULL,
	Password varchar (200) NULL,
	RoleId int NOT NULL CONSTRAINT DF_Users_RoleId DEFAULT ((0)),
	DeptId int NOT NULL CONSTRAINT DF_Users_DeptId DEFAULT ((0)),
	Position varchar (100) NULL,
	SecureMobile varchar (50) NULL,
	Disabled boolean NOT NULL CONSTRAINT DF_Users_Disabled DEFAULT false,
	BindIp text NULL,	
	State int NOT NULL CONSTRAINT DF_Users_State DEFAULT ((0)),
	LastPassTime timestamp NULL,
	LastChangePass timestamp NULL,
	EmailCapacity int NULL CONSTRAINT DF_Users_EmailCapacity DEFAULT ((-1)),
	PhotoAvatar text NULL,
	Sex int NOT NULL CONSTRAINT DF_Users_Sex DEFAULT ((1)),
	Mobile varchar (20) NULL,
	IsHideMobile boolean NOT NULL CONSTRAINT DF_Users_IsHideMobile DEFAULT false,
	TelDept varchar (50) NULL,
	Email varchar (200) NULL,
	LinkedIn text NULL,
	WhatsApp text NULL,
	Messenger text NULL,
	Teams text NULL,
	Skype text NULL,
	WeChat text NULL,	
	Theme varchar (20) NULL,
	DefaultMenu varchar (10) NULL,
	NavbarView int NOT NULL CONSTRAINT DF_Users_NavbarView DEFAULT ((1)),
	NotificationAutoPop boolean NOT NULL CONSTRAINT DF_Users_NotificationAutoPop DEFAULT true,
	EsignColor varchar (10) NULL,
	EsignTipSize varchar (10) NULL,
	Culture varchar(10) NULL,
	CredentialOptions text NULL,
	MoreOptions text NULL,
	Remark text NULL
);

CREATE TABLE User_Token
(
	TokenId BIGSERIAL PRIMARY KEY,
	TokenGuid uuid NOT NULL CONSTRAINT DF_User_Token_ParaGuid DEFAULT uuid_generate_v1(),
	TokenRandom varchar(50) NULL,
	TokenName varchar(50) NOT NULL,
	TokenUserId varchar(50) NOT NULL,
	RunId bigint NULL,
	RunData varchar(50) NULL,
	ReturnUrl text NULL,
	ValidTimeFrom timestamp NOT NULL,
	ValidTimeTo timestamp NOT NULL,
	UsedTime timestamp NULL,
	UsedIp varchar(50) NULL
);

CREATE TABLE User_Para
(
	ParaId SERIAL PRIMARY KEY,
	ParaUserId varchar(50) NULL,
	ParaName varchar(200) NOT NULL,
	ParaValue text NULL,
	ParaTime timestamp NOT NULL CONSTRAINT DF_User_Para_ParaTime DEFAULT now()
);

CREATE TABLE User_Scope(
	ScopeId SERIAL PRIMARY KEY,
	UserId varchar(50) NOT NULL,
	ScopeType varchar(50) NULL,
	ScopeDepartments text NULL,
	ScopeUsers text NULL,
	ScopeRoles text NULL
);

CREATE TABLE Sys_Para (
	ParaId SERIAL PRIMARY KEY ,
	ParaName varchar (200) NOT NULL ,
	ParaValue text NULL ,
	Remark varchar (20) NULL
);

INSERT INTO Department (DeptId,ParentDept,DeptNo,DeptName)
	VALUES (1,0,1,'缺省部门');

INSERT INTO User_Role (RoleId,RoleNo,RoleName,RoleIdString)
	VALUES (1,1,'超级管理员',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/flow/monitor/,/flow/recover/,/flow/archiving/,/flow/form/,/flow/type/,/flow/config/sort/,/flow/config/option/,/flow/config/entrust/,/flow/config/openforms/,/flow/config/esign/,/flow/config/stamp/,/office/email/,/office/team/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,/office/mgmt/ancmt/,/office/mgmt/news/,@system,/system/org/,/system/dept/,/system/user/,/system/role/,/system/appearance/,/system/connector/,/system/menu/,/system/security/,/system/log/,/system/storage/,/system/developer/,/system/info/,');

INSERT INTO User_Role (RoleId,RoleNo,RoleName,RoleIdString)
	VALUES (2,2,'总经理',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/flow/monitor/,/office/email/,/office/team/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,/office/mgmt/ancmt/,/office/mgmt/news/,');

INSERT INTO User_Role (RoleId,RoleNo,RoleName,RoleIdString)
	VALUES (3,3,'员工',',/flow/create/,/flow/list/,/flow/query/,/flow/excel/,/flow/entrust/,/office/email/,/office/team/,/office/workreport/,/office/wordpad/,/office/ancmt/,/office/news/,');

INSERT INTO Users (UserId,UserName,Password,RoleId,DeptId)
	VALUES ('admin','Administrator','CF83E1357EEFB8BDF1542850D66D8007D620E4050B5715DC83F4A921D36CE9CE47D0D13C5D85F2B0FF8318D2877EEC2F63B931BD47417A81A538327AF927DA3E',1,1);


select setval(pg_get_serial_sequence('department', 'deptid'), (select max(deptid) from department));
select setval(pg_get_serial_sequence('user_role', 'roleid'), (select max(roleId) from user_role));
select setval(pg_get_serial_sequence('users', 'id'), (select max(id) from users));

create index idx_flow_type_newuser on flow_type(newuser);
create index idx_flow_type_newdept on flow_type(newdept);
create index idx_flow_type_manageuser on flow_type(manageuser);
create index idx_flow_type_queryuser on flow_type(queryuser);
create index idx_flow_run_runname on flow_run(runname);
create index idx_flow_run_prcs_formsrandom on flow_run_prcs(formsrandom);
create index idx_flow_files_name on flow_files(name);
create index idx_office_files_name on office_files(name);
create index idx_team_work_toid on team_work(toid);